@@ -1,12 +1,9 @@
 package Games::ABC_Path::Solver::App;
-
+$Games::ABC_Path::Solver::App::VERSION = '0.6.1';
 use warnings;
 use strict;
 
 
-our $VERSION = '0.4.1';
-
-
 use parent 'Games::ABC_Path::Solver::Base';
 
 use Carp;
@@ -114,7 +111,7 @@ solving ABC Path
 
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 SYNOPSIS
 
@@ -129,7 +126,7 @@ version 0.6.0
 
 =head1 VERSION
 
-Version 0.4.1
+version 0.6.1
 
 =head1 FUNCTIONS
 
@@ -229,7 +226,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/games-abc_path-solver/issues>
+L<https://github.com/shlomif/abc-path/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -338,7 +335,7 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/games-abc_path-solver>
+L<https://github.com/shlomif/abc-path>
 
   git clone https://github.com/shlomif/abc-path
 
