@@ -1,5 +1,5 @@
 package Games::ABC_Path::Solver::Constants;
-$Games::ABC_Path::Solver::Constants::VERSION = '0.6.0';
+$Games::ABC_Path::Solver::Constants::VERSION = '0.6.1';
 use strict;
 use warnings;
 
@@ -38,11 +38,11 @@ B<FOR INTERNAL USE!>.
 
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 AUTHOR
 
@@ -127,7 +127,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/games-abc_path-solver/issues>
+L<https://github.com/shlomif/abc-path/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -236,7 +236,7 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/games-abc_path-solver>
+L<https://github.com/shlomif/abc-path>
 
   git clone https://github.com/shlomif/abc-path
 
