@@ -1,5 +1,5 @@
 package Games::ABC_Path::Solver::Move::LastRemainingLetterForCell;
-$Games::ABC_Path::Solver::Move::LastRemainingLetterForCell::VERSION = '0.6.0';
+$Games::ABC_Path::Solver::Move::LastRemainingLetterForCell::VERSION = '0.6.1';
 use strict;
 use warnings;
 
@@ -26,7 +26,7 @@ that indicates it's the last remaining letter for a given cell.
 
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 SYNOPSIS
 
@@ -49,7 +49,7 @@ letter as C<'letter'>.
 
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 AUTHOR
 
@@ -134,7 +134,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/games-abc_path-solver/issues>
+L<https://github.com/shlomif/abc-path/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -243,7 +243,7 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/games-abc_path-solver>
+L<https://github.com/shlomif/abc-path>
 
   git clone https://github.com/shlomif/abc-path
 
